class PanelPicture < ActiveRecord::Base
  belongs_to :panel
  belongs_to :picture
  
  validates :panel_id, :numericality => {:allow_blank => true}
  validates :picture_id, :numericality => true, :existence => true
  validates :link, :length => {:maximum => 200}, :url => {:allow_blank => true}
  validates :x, :presence => true, :numericality => true
  validates :y, :presence => true, :numericality => true
  validates :width, :presence => true, :numericality => true, :not_zero => true, :reverse => true, :resize => true, :sync_vh => true
  validates :height, :presence => true, :numericality => true, :not_zero => true, :reverse => true, :resize => true, :sync_vh => true
  validates :z, :presence => true, :numericality => {:greater_than => 0}
  validates :t, :presence => true, :numericality => {:greater_than_or_equal_to => 0}
  
  def flip
    res = (self.height < 0 ? '' : 'v') + (self.width == 0 ? '' : 'h')
    res += '/' unless res.empty?
    res
  end
  
  def filename
    flip + self.resource_picture.filename
  end
  
  def url
    '/pictures/' + self.picture.filename
  end
  
  def self.default_page_size
    25
  end
  
  def self.max_page_size
    100
  end
  
  def self.page prm = nil
    page = prm.to_i
    page = 1 if page < 1
    page
  end
  
  def self.page_size prm = self.default_page_size
    page_size = prm.to_i
    page_size = self.max_page_size if page_size > self.max_page_size
    page_size = self.default_page_size if page_size < 1
    page_size
  end
  
  def self.list page = 1, page_size = self.default_page_size
    opt = {}
    opt.merge!(PanelPicture.list_opt)
    opt.merge!({:limit => page_size, :offset => (page -1) * page_size}) if page_size > 0
    opt.merge!({:conditions => 'panels.publish > 0', :order => 'panel_pictures.updated_at desc'})
    PanelPicture.find(:all, opt)
  end
  
  def self.list_opt
    {:include => {:panel => {:author => {}}, :picture => {:artist => {}, :license => {}}}}
  end
  
  def self.list_json_opt
    {:include => {:panel => {:include => {:author => {}}}, :picture => {:include => {:artist => {}, :license => {}}} }}
  end
  
  def self.mylist au, page = 1, page_size = Author.default_panel_picture_page_size
    opt = {}
    opt.merge!(PanelPicture.list_opt)
    opt.merge!({:limit => page_size, :offset => (page -1) * page_size}) if page_size > 0
    opt.merge!({:conditions => ['panels.author_id = ?', au.id], :order => 'panel_pictures.updated_at desc'})
    PanelPicture.find(:all, opt)
  end
  
end
