class SystemPicture < ActiveRecord::Base
  has_many :balloons
  has_many :balloon_templates
  has_many :licenses
  
  validates :ext, :presence => true, :length => {:maximum => 4}, :inclusion => {:in => ['png', 'jpeg', 'gif']}
  validates :width, :presence => true, :numericality => true, :natural_number => true
  validates :height, :presence => true, :numericality => true, :natural_number => true
  validates :filesize, :presence => true, :numericality => {:greater_than => 0, :less_than_or_equal_to => 2000000}, :natural_number => true
  validates :md5, :presence => true, :length => {:minimum => 32, :maximum => 32}
  
  before_destroy :destroy_with_file
  
  def destroy_with_file
    PictureIO.system_picture_io.delete self.filename
  end
  
  def supply_default
  end
  
  def overwrite
  end
  
  def own? ad
    true
  end
  
  def visible? ad
    true
  end
  
  def filename
    "#{self.id}.#{self.ext}"
  end
  
  def mime_type
    "image/#{self.ext}"
  end
  
  def url
    '/system_pictures/' + filename
  end
  
  def self.default_page_size
    25
  end
  
  def self.max_page_size
    100
  end
  
  def self.page prm = nil
    page = prm.to_i
    page = 1 if page < 1
    page
  end
  
  def self.page_size prm = self.default_page_size
    page_size = prm.to_i
    page_size = self.max_page_size if page_size > self.max_page_size
    page_size = self.default_page_size if page_size < 1
    page_size
  end
  
  def self.list page = 1, page_size = self.default_page_size
    opt = {}
    opt.merge!(self.list_opt)
    opt.merge!({:limit => page_size, :offset => (page -1) * page_size}) if page_size > 0
    opt.merge!({:order => 'system_pictures.updated_at desc'})
    SystemPicture.find(:all, opt)
  end
  
  def self.list_opt
    {}
  end
  
  def self.list_json_opt
    {}
  end
  
  def self.show sid, ad
    opt = {}
    opt.merge!(self.show_opt)
    res = SystemPicture.find(sid, opt)
    raise ActiveRecord::Forbidden unless res.visible?(ad)
    res
  end
  
  def self.show_opt
    {}
  end
  
  def self.show_json_opt
    {}
  end
  
  def store(imager)
    unless imager
      self.errors.add :base, 'illegal picture data'
      return false
    end
    res = false
    SystemPicture.transaction do
      if res = self.save
        if res = PictureIO.system_picture_io.put(imager.binary, self.filename)
          res = true
        else
          self.errors.add :base, 'system picture io does not work'
          raise ActiveRecord::Rollback
        end
      end
    end
    res
  end
  
  def self.store(imager)
    attr = {:ext => imager.ext, :width => imager.width, :height => imager.height, :filesize => imager.filesize, :md5 => imager.md5}
    sp = SystemPicture.modify_object(imager.md5, attr, 'md5')
    res = sp.store imager
    res ? sp : nil
  end
  
  def restore(subdir = nil)
    PictureIO.system_picture_io.get self.filename, subdir
  end
  
end
